@@ -1,7 +1,8 @@
 #!/bin/bash
 
 if [ $(uname) == Linux ]; then
-    ar vx pandoc*.deb
+    # conda-build tries to be smarted than you an unpackas debs now :-/
+    # ar vx pandoc.deb
     tar --extract --xz --verbose --file=data.tar.xz
     mkdir -p $PREFIX/bin
     mv usr/bin/* $PREFIX/bin
@@ -9,7 +10,7 @@ fi
 
 
 if [ $(uname) == Darwin ]; then
-    pkgutil --expand pandoc-$PKG_VERSION-macOS.pkg pandoc
+    pkgutil --expand pandoc.pkg pandoc
     cpio -i -I pandoc/pandoc.pkg/Payload
     mkdir -p $PREFIX/bin
     cp usr/local/bin/* $PREFIX/bin/
